### Name: plot.trackdata
### Title: Produces time-series plots from trackdata
### Aliases: plot.trackdata
### Keywords: dplot

### ** Examples


# a single segment of trackdata (F1) plotted as a function of time.
plot(vowlax.fdat[1,1])

# as above, but limits are set for the time axis.
plot(vowlax.fdat[1,1], xlim=c(880, 920))

# the same as above but the start-time of the x-axis is also set to 0 ms
plot(vowlax.fdat[1,1], xlim=c(880, 920), timestart=0)

# a single segment of trackdata (sampled speech data) plotted as a function of time.
plot(coutts.sam[1,], type="l")

# as above, but limits are set for the time axis.
plot(coutts.sam[1,], type="l", xlim=c(16200, 16300))

# the same as above but the start-time of the x-axis is also set to 0 ms
plot(coutts.sam, type="l", timestart=0, xlim=c(16200, 16300))

# get some labels
labs = label(coutts)

# superimpose these on the plot
plot(coutts.sam, type="l", timestart=0, labels=labs)

# plot each segment in its own window.
par(mfrow=c(2,3))
plot(coutts.sam, type="l", labels=labs, contig=FALSE)

# plot each segment in its own window and set timestart to 0 ms, set the colour to red
par(mfrow=c(2,3))
plot(coutts.sam, type="l", labels=labs, timestart=0, contig=FALSE, col="red")

# F1 and F2 of six vowels with labels

par(mfrow=c(2,3))
plot(vowlax.fdat[1:6,1:2], contig=FALSE, labels=vowlax.l[1:6], ylab="F1 and F2", 
xlab="Time (ms)", type="b", ylim=c(300, 2400))




